1.1
~~~~

* Release date: 23 May, 2025.
* Support for MPIv4 and mpi4py version 4.x.
* Support for NumPy 2.0 and Cython 3.0.
* Use github actions now.
* Add support to set the build options in ``~/.compyle/config.py``.
* Minor fixes for the test files.

1.0.1
~~~~~~

* Release date: 1 December, 2018.
* Minor release fixing setup.py requirements.

1.0
~~~

* Release date: 1 December, 2018.
* First public release as a separate project that is pip installable.
* Support for properties with strides.
* Do not initialize MPI automatically but let users do so explicitly.
* CI tests on travis and full documentation builds on readthedocs.
* Update build instructions for Ubuntu and conda.
* Remove carray as it is now a separate package called cyarray.
